@@ -437,16 +437,13 @@ class Update:
             idp_user = self._prepare_idp_user(person)
 
             updates = []
-            patch = {}
 
             for key in sorted(idp_user):
                 new = idp_user[key]
                 old = user.get(key)
                 if new != old:
                     updates.append(f"  {key}: {old} -> {new}")
-                    patch[key] = new
                     user[key] = new
-
             if updates:
                 print(f"\nUpdating user: {email}...")
                 print("\n".join(updates))
